@@ -41,12 +41,12 @@ If using PROTOTYPES, then PROTO_LIST returns the list, otherwise it
 
 /* MD5 context. */
 typedef struct {
-  UINT4 state[4];                                   /* state (ABCD) */
-  UINT4 count[2];        /* number of bits, modulo 2^64 (lsb first) */
+UINT4 state[4];                                   /* state (ABCD) */
+UINT4 count[2];        /* number of bits, modulo 2^64 (lsb first) */
   unsigned char buffer[64];                         /* input buffer */
 } MD5_CTX;
 
 void MD5Init PROTO_LIST ((MD5_CTX *));
 void MD5Update PROTO_LIST
   ((MD5_CTX *, unsigned char *, unsigned int));
-void MD5Final PROTO_LIST ((unsigned char [16], MD5_CTX *));
+unsigned int *MD5Final PROTO_LIST ((unsigned char [16], MD5_CTX *));
